@@ -13,16 +13,25 @@ use crate::base::compress;
 use crate::base::fileset::copy_filesets;
 use crate::base::Arch;
 use crate::config::{Config, LinuxConfig};
-use crate::BuildError;
+use crate::error::{Error, ErrorKind};
 
-pub fn build_rpm(conf: &Config, linux_conf: &LinuxConfig, _arch: Arch) -> Result<(), BuildError> {
+pub fn build_rpm(conf: &Config, linux_conf: &LinuxConfig, _arch: Arch) -> Result<(), Error> {
+    log::info!("build_rpm() conf: {:?}", conf);
     let rpm_conf = &linux_conf.rpm;
 
     let workdir = Path::new(&conf.metadata.workdir);
     let rpm_dir = workdir.join("rpm");
     fs::create_dir_all(&rpm_dir)?;
     let spec_file = rpm_dir.join(format!("{}.spec", &conf.metadata.name));
-    let mut spec_fd = File::create(&spec_file)?;
+    let mut spec_fd = File::create(&spec_file).map_err(|err| {
+        Error::from_string(
+            ErrorKind::IoError,
+            format!(
+                "Failed to create rpm spec file {:?}, error: {:?}",
+                &spec_file, err
+            ),
+        )
+    })?;
     let source_dir = rpm_dir.join(&format!(
         "{}-{}",
         &conf.metadata.name, &conf.metadata.version
@@ -37,7 +46,10 @@ pub fn build_rpm(conf: &Config, linux_conf: &LinuxConfig, _arch: Arch) -> Result
     } else if let Some(files) = linux_conf.files.as_ref() {
         files
     } else {
-        return Err(BuildError::FilesNotSet);
+        return Err(Error::new(
+            ErrorKind::FilesNotSet,
+            "`files` property not set for rpm format",
+        ));
     };
     copy_filesets(files, &conf.metadata.src_dir, &source_dir)?;
 
@@ -60,7 +72,9 @@ fn generate_spec_file(
     conf: &Config,
     rpm_conf: &RpmConfig,
     spec_fd: &mut File,
-) -> Result<(), BuildError> {
+) -> Result<(), Error> {
+    log::info!("generate_spec_file()");
+
     // Generate spec file.
     writeln!(spec_fd, "Name: {}", &conf.metadata.name)?;
     writeln!(spec_fd, "Version: {}", &conf.metadata.version)?;
@@ -109,7 +123,12 @@ cp -rfa * %{{buildroot}}
     Ok(())
 }
 
-fn generate_rpm_file(spec_file: &Path, rpm_dir: &Path) -> Result<(), BuildError> {
+fn generate_rpm_file(spec_file: &Path, rpm_dir: &Path) -> Result<(), Error> {
+    log::info!(
+        "generate_rpm_file() spec: {:?}, rpm_dir: {:?}",
+        spec_file,
+        rpm_dir
+    );
     let def = format!("_topdir {}", fs::canonicalize(rpm_dir)?.display());
     let status = Command::new("rpmbuild")
         // Change rootdir of rpm build.
@@ -117,10 +136,19 @@ fn generate_rpm_file(spec_file: &Path, rpm_dir: &Path) -> Result<(), BuildError>
         .arg(&def)
         .arg("-bb")
         .arg(spec_file)
-        .status()?;
+        .status()
+        .map_err(|err| {
+            Error::from_string(
+                ErrorKind::RpmCompilerError,
+                format!("Failed to run `rpmbuild` command, error: {:?}, please check `rpm` package is installed", err),
+            )
+        })?;
     if status.success() {
         Ok(())
     } else {
-        Err(BuildError::RpmCompilerError)
+        Err(Error::from_string(
+            ErrorKind::RpmCompilerError,
+            format!("rpm file: {:?}", spec_file),
+        ))
     }
 }
